@@ -230,7 +230,12 @@ visualize_term_interactions <- function(result_df, pin_name_path) {
                                               gravity = "northeast",
                                               offset = "+10+10")
 
+      # remove forbidden characters
       current_row$Term_Description <- gsub('[ :<>?*|"/\\]', "_", current_row$Term_Description)
+
+      # limit to 100 characters
+      current_row$Term_Description <- substr(current_row$Term_Description, 1, min(100, nchar(current_row$Term_Description)))
+
       path_to_png <- file.path("term_visualizations",
                                paste0(current_row$Term_Description, ".png"))
 
